/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsIPrefBranch2">
 **/

package org.mozilla.xpcom;

public interface nsIPrefBranch2 extends nsIPrefBranch
{
  public static final String NS_IPREFBRANCH2_IID =
    "{74567534-eb94-4b1c-8f45-389643bfc555}";

  public void addObserver(String arg1, nsIObserver arg2, boolean arg3);

  public void removeObserver(String arg1, nsIObserver arg2);

}
